﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace WebTab
{
    public partial class frmmain : Form
    {
        private enum TCommands { OPEN,BACK, FORWARD,STOP, REFRESH, HOME,FIND }

        public frmmain()
        {
            InitializeComponent();
        }

        private void DocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
        {
            WebBrowser wb = GetWebBrowser();

            if (string.IsNullOrEmpty(wb.DocumentTitle))
            {
                //Set tab caption
                sTab1.SelectedTab.Text = "Blank Page";
            }
            else
            {
                //Set tab caption with webpage title
                sTab1.SelectedTab.Text = wb.DocumentTitle;
            }
        }

        private void DoCommand(TCommands option)
        {
            WebBrowser wb = GetWebBrowser();
            wb.Focus();

            switch (option)
            {
                case TCommands.OPEN:
                    SendKeys.Send("^o");
                    break;
                case TCommands.BACK:
                    wb.GoBack();
                    break;
                case TCommands.FORWARD:
                    wb.GoForward();
                    break;
                case TCommands.STOP:
                    wb.Stop();
                    break;
                case TCommands.REFRESH:
                    wb.Refresh();
                    break;
                case TCommands.HOME:
                    wb.GoHome();
                    break;
                case TCommands.FIND:
                    SendKeys.Send("^f");
                    break;
            }
        }

        private WebBrowser GetWebBrowser()
        {
            TabPage tp = sTab1.SelectedTab;

            if (tp != null)
            {
                return (WebBrowser)tp.Controls[0];
            }
            return null;
        }

        private void NewTab(string caption)
        {
            TabPage tp = new TabPage(caption);
            WebBrowser wb = new WebBrowser();
            //Fill the tab
            wb.Dock = DockStyle.Fill;
            wb.DocumentCompleted += new WebBrowserDocumentCompletedEventHandler(DocumentCompleted);
            //navigate to blank page
            wb.Navigate("about:blank");
            //Add webbroswer to tabpage
            tp.Controls.Add(wb);
            //Add tabpage to tabs control
            sTab1.TabPages.Add(tp);
            txtAddr.Text = "about:blank";
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            NewTab("Blank page");
        }

        private void mnuNewTab_Click(object sender, EventArgs e)
        {
            //Create new tab 
            NewTab("BlankPage");
        }

        private void txtAddr_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == '\r')
            {
                //Cancel out beep sound
                e.Handled = true;
                //Rasie button click event
                cmdGo_Click(sender, e);
            }
        }

        private void cmdGo_Click(object sender, EventArgs e)
        {
            if (txtAddr.Text.Trim().Length > 0)
            {
                WebBrowser wb = GetWebBrowser();
                //Navigate to the page
                wb.Navigate(txtAddr.Text);
            }
        }

        private void cmdBack_Click(object sender, EventArgs e)
        {
            //Go back
            DoCommand(TCommands.BACK);
        }

        private void cmdForward_Click(object sender, EventArgs e)
        {
            //Go forward
            DoCommand(TCommands.FORWARD);
        }

        private void cmdStop_Click(object sender, EventArgs e)
        {
            //Stop
            DoCommand(TCommands.STOP);
        }

        private void cmdRefresh_Click(object sender, EventArgs e)
        {
            //Refresh
            DoCommand(TCommands.REFRESH);
        }

        private void cmdHome_Click(object sender, EventArgs e)
        {
            //Go home
            DoCommand(TCommands.HOME);
        }

        private void cmdFind_Click(object sender, EventArgs e)
        {
            //Find text in webpage
            DoCommand(TCommands.FIND);
        }

        private void mnuCloseTab_Click(object sender, EventArgs e)
        {
            if (sTab1.TabPages.Count > 1)
            {
                //Destroy tab
                sTab1.SelectedTab.Dispose();
            }
        }

        private void cmdOpen_Click(object sender, EventArgs e)
        {
            //Open webpage
            DoCommand(TCommands.OPEN);
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }

    }
}
